@@ -13,7 +13,7 @@
 mod explore;
 
 pub mod model;
-pub mod simulate;
+//pub mod simulate;
 pub mod time;
 
 pub use explore::*;
